@@ -161,6 +161,15 @@ MONGOCTL_PARSER_DEF = {
                             "its not added yet",
                     "default": False
                 },
+                    {
+                    "name": "installCompatible",
+                    "type" : "optional",
+                    "cmd_arg": "--install-mongodb",
+                    "nargs": 0,
+                    "help": "Automatically installs MongoDB compatible with "
+                            "server if no compatible installation found",
+                    "default": False
+                },
 
                     {
                     "name": "username",
